@@ -275,7 +275,7 @@ int zmq_socket_monitor_versioned (void *s_,
     zmq::socket_base_t *s = as_socket_base_t (s_);
     if (!s)
         return -1;
-    return s->monitor (addr_, events_, event_version_);
+    return s->monitor (addr_, events_, event_version_, ZMQ_PAIR);
 }
 
 int zmq_socket_monitor (void *s_, const char *addr_, int events_)
@@ -283,6 +283,16 @@ int zmq_socket_monitor (void *s_, const char *addr_, int events_)
     return zmq_socket_monitor_versioned (s_, addr_, events_, 1);
 }
 
+int zmq_socket_monitor_versioned_typed (
+  void *s_, const char *addr_, uint64_t events_, int event_version_, int type_)
+{
+    zmq::socket_base_t *s = as_socket_base_t (s_);
+    if (!s)
+        return -1;
+
+    return s->monitor (addr_, events_, event_version_, type_);
+}
+
 int zmq_join (void *s_, const char *group_)
 {
     zmq::socket_base_t *s = as_socket_base_t (s_);
@@ -1278,6 +1288,17 @@ int zmq_poller_wait_all (void *poller_,
     return rc;
 }
 
+int zmq_poller_fd (void *poller_, zmq_fd_t *fd_)
+{
+    if (!poller_
+        || !(static_cast<zmq::socket_poller_t *> (poller_)->check_tag ())) {
+        errno = EFAULT;
+        return -1;
+    } else {
+        return static_cast<zmq::socket_poller_t *> (poller_)->signaler_fd (fd_);
+    }
+}
+
 //  Peer-specific state
 
 int zmq_socket_get_peer_state (void *s_,
