@@ -125,7 +125,7 @@ else
 }
 
 
-if ($is_linux || $is_osx || ($is_bsd && !$is_gkfreebsd && !$is_openbsd))
+if ($is_linux || $is_osx)
 {
 	push @opts,
 		'ZMQ_HAVE_TCP_KEEPCNT',
